==> vmp-0.7.1.tar.xz: vmp-0.7.1/framework/python/vmp_crypto/__init__.py <==
#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 02/10/2024

import vmp
import vmp_net
import vmp_event

from vmp_crypto_  import init as init
from vmp_crypto_  import end  as end

from vmp_crypto_  import sslui as sslui
from vmp_crypto_  import SslUI as SslUI

from vmp_crypto_  import md5        as md5
from vmp_crypto_  import md5_bin    as md5_bin
from vmp_crypto_  import sha1       as sha1
from vmp_crypto_  import sha1_bin   as sha1_bin
from vmp_crypto_  import sha224     as sha224
from vmp_crypto_  import sha224_bin as sha224_bin
from vmp_crypto_  import sha256     as sha256
from vmp_crypto_  import sha256_bin as sha256_bin
from vmp_crypto_  import sha384     as sha384
from vmp_crypto_  import sha384_bin as sha384_bin
from vmp_crypto_  import sha512     as sha512
from vmp_crypto_  import sha512_bin as sha512_bin

from vmp_crypto_  import PKey as PKey
from vmp_crypto_  import X509_Wrap as X509_Wrap

from vmp_crypto_  import Ctx  as Ctx
from vmp_crypto_  import Ctx_Base_Tls_Client as Ctx_Base_Tls_Client
from vmp_crypto_  import Ctx_Base_Tls_Server as Ctx_Base_Tls_Server
from vmp_crypto_  import Ctx_Https_Tls       as Ctx_Https_Tls 

from vmp_crypto_  import Ctx_Peer_Acl  as Ctx_Peer_Acl
from vmp_crypto_  import Ctx_Peer      as Ctx_Peer
from vmp_crypto_  import Ctx_Peer_Web  as Ctx_Peer_Web

from vmp_crypto_  import Ssl as Ssl

==> vmp-0.7.3.tar.xz: vmp-0.7.3/framework/python/vmp_crypto/__init__.py <==
#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 20/03/2025

import vmp
import vmp_net
import vmp_event

from vmp_crypto_  import init as init
from vmp_crypto_  import end  as end

from vmp_crypto_  import sslui as sslui
from vmp_crypto_  import SslUI as SslUI

from vmp_crypto_  import ssl_shutdown  as ssl_shutdown

from vmp_crypto_  import md5        as md5
from vmp_crypto_  import md5_bin    as md5_bin
from vmp_crypto_  import sha1       as sha1
from vmp_crypto_  import sha1_bin   as sha1_bin
from vmp_crypto_  import sha224     as sha224
from vmp_crypto_  import sha224_bin as sha224_bin
from vmp_crypto_  import sha256     as sha256
from vmp_crypto_  import sha256_bin as sha256_bin
from vmp_crypto_  import sha384     as sha384
from vmp_crypto_  import sha384_bin as sha384_bin
from vmp_crypto_  import sha512     as sha512
from vmp_crypto_  import sha512_bin as sha512_bin

from vmp_crypto_  import PKey as PKey
from vmp_crypto_  import X509_Wrap as X509_Wrap

from vmp_crypto_  import Ctx  as Ctx
from vmp_crypto_  import Ctx_Base_Tls_Client as Ctx_Base_Tls_Client
from vmp_crypto_  import Ctx_Base_Tls_Server as Ctx_Base_Tls_Server
from vmp_crypto_  import Ctx_Https_Tls       as Ctx_Https_Tls 

from vmp_crypto_  import Ctx_Peer_Acl  as Ctx_Peer_Acl
from vmp_crypto_  import Ctx_Peer      as Ctx_Peer
from vmp_crypto_  import Ctx_Peer_Web  as Ctx_Peer_Web

from vmp_crypto_  import Ssl    as Ssl
from vmp_crypto_  import SslBio as SslBio
